@@ -2,11 +2,16 @@ from .adjacencies import adjacencies
 from .assign import assign
 from .indexed_geometries import IndexedGeometries
 from .intersections import intersections, prorate
-from .repair import close_gaps, resolve_overlaps, make_valid, autorepair, snap_to_grid, crop_to, doctor
+from .repair import close_gaps, resolve_overlaps, make_valid, autorepair, snap_to_grid, crop_to, expand_to, doctor
 from .normalize import normalize
 from .progress_bar import progress
 
-__version__ = "0.6"
+import geopandas
+
+# mitigate https://github.com/geopandas/geopandas/issues/2199
+geopandas.options.use_pygeos = False  
+
+__version__ = "1.0.5"
 __all__ = [
     "assign",
     "intersections",
